@@ -10,14 +10,18 @@ __author__ = 'Matt Joyce'
 __email__ = 'matt@joyce.nyc'
 __copyright__ = 'Copyright 2016, Symphony Communication Services LLC'
 
+from nopkcs import NOPKCS
 
-class RESTful():
-    from .base import GET_query
-    from .base import POST_query
 
-    def __init__(self, url, crt, key, session, keymngr):
+class RESTful(NOPKCS):
+
+    def __init__(self, url, session, keymngr):
         self.__url__ = url
-        self.__crt__ = crt
-        self.__key__ = key
         self.__session__ = session
         self.__keymngr__ = keymngr
+
+    def bool2str(self, boolval):
+        if boolval:
+            return 'true'
+        else:
+            return 'false'
